# csr_aws_utils
Utility functions for AWS Cloud

## CI status
[![Build and Test Status]( https://engci-private-rtp.cisco.com/jenkins/ent-routing/job/CSR/job/csr_aws_utils_postmerge/badge/icon)]( https://engci-private-rtp.cisco.com/jenkins/ent-routing/job/CSR/job/csr_aws_utils_postmerge)
